
**************************************************************************
**************************************************************************
**      BASIC CLEANING OF UWEZO DATA + MERGING WITH EXTERNAL DATA       **
**************************************************************************
**************************************************************************

* Uwezo data: for each country, combine waves + define main variables 
do create_data_KE.do
do create_data_TZ.do

* create rainfall and night lights data from GIS raw data
do create_rainfall.do
do create_night_lights.do

* load and combine country-specific Uwezo datasets
use KE_clean.dta, clear
append using TZ_clean.dta

* create IPUMS district identifiers + merge in rainfall and night lights data
do create_IPUMS_districts.do
sort country id_district_IPUMS cohort
merge m:1 country id_district_IPUMS cohort using KE_TZ_rainfall.dta
keep if _merge == 3
drop _merge
merge m:1 country id_district_IPUMS cohort using KE_TZ_night_lights.dta
keep if _merge == 3
drop _merge


**************************************************************************
**************************************************************************
**                 SOME FURTHER ADJUSTMENTS TO VARIABLES                **
**************************************************************************
**************************************************************************

* create numeric household ID
egen double id_hh_new = group(id_hh_str)

* create mother ID
egen id_mother = group(id_hh_str mothers_edu_orig mothers_age), mis
gen str23 id_mother_str = id_hh_str + string(id_mother, "%07.0f")

* for those currently in preschool: set any_preschool to 1
replace any_preschool = 1 if preschool == 1

* for those currently enrolled in preschool: set neverenrolled to 0
replace neverenrolled = 0 if preschool == 1

* students who dropped out after less than 1 year of school: set neverenrolled to 1
tab dropout_class
replace neverenrolled = 1 if dropout_class <= 1

* define enrolment variable combining preschool and in_school
tab preschool in_school
gen current_enrollment = 1 if preschool == 1
replace current_enrollment = 2 if preschool == 0 & in_school == 1
replace current_enrollment = 3 if current_enrollment == .
label define current_enrollment 1 "1 - in preschool" 2 "2 - in school" 3 "3 - dropped out" 
label values current_enrollment current_enrollment

* define hh size as number of children in hh
rename hh_size hh_size_old
gen one = 1
bysort id_hh_str: egen hh_size = total(one)
drop one

* regional economic variables only up to 5 years in KE
replace neg_rainfall_shock_y6 = 0 if country == 1
replace pos_rainfall_shock_y6 = 0 if country == 1
replace mean_lights_y6 = 0 if country == 1

* regional economic variables: define summary measures 
egen aux_KE = rowtotal(neg_rainfall_shock_y0 neg_rainfall_shock_y1 neg_rainfall_shock_y2 neg_rainfall_shock_y3 neg_rainfall_shock_y4 neg_rainfall_shock_y5) if country == 1
egen aux_TZ = rowtotal(neg_rainfall_shock_y0 neg_rainfall_shock_y1 neg_rainfall_shock_y2 neg_rainfall_shock_y3 neg_rainfall_shock_y4 neg_rainfall_shock_y5 neg_rainfall_shock_y6) if country == 2
gen n_neg_rainfall_shocks = aux_KE if country == 1
replace n_neg_rainfall_shocks = aux_TZ if country == 2
drop aux*
label var n_neg_rainfall_shocks "Negative rainfall shocks"

egen aux_KE = rowtotal(pos_rainfall_shock_y0 pos_rainfall_shock_y1 pos_rainfall_shock_y2 pos_rainfall_shock_y3 pos_rainfall_shock_y4 pos_rainfall_shock_y5) if country == 1
egen aux_TZ = rowtotal(pos_rainfall_shock_y0 pos_rainfall_shock_y1 pos_rainfall_shock_y2 pos_rainfall_shock_y3 pos_rainfall_shock_y4 pos_rainfall_shock_y5 pos_rainfall_shock_y6) if country == 2
gen n_pos_rainfall_shocks = aux_KE if country == 1
replace n_pos_rainfall_shocks = aux_TZ if country == 2
drop aux*
label var n_pos_rainfall_shocks "Positive rainfall shocks"

egen aux_KE = rowmean(mean_lights_y0  mean_lights_y1 mean_lights_y2 mean_lights_y3 mean_lights_y4 mean_lights_y5) if country == 1
egen aux_TZ = rowmean(mean_lights_y0  mean_lights_y1 mean_lights_y2 mean_lights_y3 mean_lights_y4 mean_lights_y5 mean_lights_y6) if country == 2
gen total_mean_lights = aux_KE if country == 1
replace total_mean_lights = aux_TZ if country == 2
drop aux*
label var total_mean_lights "Log night light density"

* highest grade completed: at most 2 years ahead
gen max_highest_grade = age - 6 + 2 if country == 1
replace max_highest_grade = age - 7 + 2 if country == 2
replace highest_grade_completed = max_highest_grade if (highest_grade_completed > max_highest_grade) & highest_grade_completed!=.

* define highest grade attended
gen highest_grade_attended = 0 if preschool == 1
replace highest_grade_attended = grade if highest_grade_attended == . & enr_ans == 1
replace highest_grade_attended = dropout_class if highest_grade_attended == . & dropout == 1
replace highest_grade_attended = max_highest_grade if (highest_grade_attended > max_highest_grade) & highest_grade_attended != .

* define age span control (span between youngest and oldest child in household)
bysort id_mother: egen oldest = max(age)
bysort id_mother: egen youngest = min(age)
bysort id_mother: gen age_span = oldest - youngest
drop oldest youngest


**************************************************************************
**************************************************************************
**                         SAMPLE RESTRICTIONS                          **
**************************************************************************
**************************************************************************

count // 690,934

* restrict ages
tab age country
tab age country [aw=weight], col nof 
drop if age < 7  & country == 1
drop if age < 8  & country == 2

* drop children who never enrolled in (pre)school
drop if neverenrolled == 1


* keep only children with non-missing info on at least one of the key outcomes
keep if math != . | highest_grade_completed != .

count // 517,096


**************************************************************************
**************************************************************************
**     GENERATE INDICATOR FOR HAVING 2ND-GRADE LITERACY & NUMERACY      **
**************************************************************************
**************************************************************************

gen has_all_scores = 0
replace has_all_scores = 1 if math != . & english !=. & swahili !=.

replace has_all_scores = 1

tab english, nol // max = 4
tab swahili, nol // max = 4
tab math, nol // max = 6
gen g2_lit_num = 0 if math != . | english != . | swahili !=.
replace g2_lit_num = 1 if ((math == 6 & swahili == 4) | (math == 6 & english == 4)) & has_all_scores == 1

replace g2_lit_num = 1 if math == . & (swahili == 4 | english == 4)
replace g2_lit_num = 1 if english == . & ((math == 6 & swahili == .) | (math == . & swahili == 4))
replace g2_lit_num = 1 if swahili == . & ((math == 6 & english == .) | (math == . & english == 4))


**************************************************************************
**************************************************************************
**         GENERATE STANDARDIZED WEALTH INDEX AND TEST SCORES           **
**************************************************************************
**************************************************************************

* generate standardized wealth index
gen double hh_wealth_std=.
levelsof country, local(lcntry)
foreach c of local lcntry {
		qui sum hh_wealth [aw=weight] if country==`c'
		replace hh_wealth_std=(hh_wealth-r(mean))/sqrt(r(Var)) if country==`c'
}

label var hh_wealth_std "Household wealth index" 

* generate standardized test scores
gen math_std = .
levelsof country, local(lcntry)
levelsof wave, local(lwave)
levelsof testsample, local(ltest)
levelsof age, local(lage)
foreach c of local lcntry {
		foreach w of local lwave {
				foreach t of local ltest {
						foreach a of local lage {
								qui sum math [aw = weight] if country == `c' & wave == `w' & testsample == `t' & age == `a' & has_all_scores == 1
								replace math_std = (math - r(mean)) / sqrt(r(Var)) if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
                        }
                }
		}
}


gen english_std=.
foreach c of local lcntry {
		foreach w of local lwave {
				foreach t of local ltest {
						foreach a of local lage {
								qui sum english [aw=weight] if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
								replace english_std=(english-r(mean))/sqrt(r(Var)) if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
                        }
                }
		}
}

gen swahili_std=.
foreach c of local lcntry {
		foreach w of local lwave {
				foreach t of local ltest {
						foreach a of local lage {
								qui sum swahili [aw=weight] if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
								replace swahili_std=(swahili-r(mean))/sqrt(r(Var)) if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
                        }
                }
		}
}

egen mean_score = rowmean(math_std english_std swahili_std) if has_all_scores == 1
gen mean_score_std = .
foreach c of local lcntry {
		foreach w of local lwave {
				foreach t of local ltest {
						foreach a of local lage {
								qui sum mean_score [aw=weight] if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
								replace mean_score_std=(mean_score-r(mean))/sqrt(r(Var)) if country==`c' & wave==`w' & testsample==`t' & age==`a' & has_all_scores == 1
                        }
                }
		}
}


**************************************************************************
**************************************************************************
**          CREATE VARIABLE AND VALUE LABELS AND SAVE DATASET
**************************************************************************
**************************************************************************

label define country 1 "Kenya" 2 "Tanzania" 
label values country country

label var female "Female"
label var age "Age"
label variable cohort "Cohort"
label variable birth_order "Birth order"
label variable mothers_edu "Mother's education"
label var hh_size "No. of children in HH"
label var hh_wealth_std "Current household wealth (index)"
label var rural "Rural location"
label var age_span "Sibling age span"

label variable any_preschool "Attended preschool"
label var years_preschool "Years of preschool"
label var years_preschool_winsorized "Years of preschool"

label var mean_score_std "Composite test score"
label var highest_grade_attended "Highest grade attended"
label var in_school "Currently enrolled"
label var g2_lit_num "Has 2nd-grade lit./num. skills"
label var math "Raw math score"
label var english "Raw English score"
label var swahili "Raw Swahili score"
label var dropout "Dropped out of school"

xtset id_mother

compress
saveold clean_all.dta, replace version(13)
